/*
 * Ben NanoNote and EM027AS012 E-Paper Display Adapter Board communication.
 *
 * Copyright (C) 2013 Paul Boddie
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <ubb/ubb.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <signal.h>
#include "images.h"
#include "Display_Controller.h"
#include "bsp.h"

/**
 * Handle termination of the process.
 */
void shutdown(int signum)
{
    printf("Closing...\n");
    ubb_close(0);
    exit(1);
}

/* Main program and basic initialisation. */

int main(int argc, char *argv[])
{
    uint8_t *current_image, blank_image[176][33];

    signal(SIGINT, &shutdown);

    if (ubb_open(0) < 0) {
        perror("ubb_open");
        return 1;
    }

    ubb_power(1);
    printf("Power on.\n");

    /* Need to initialise the board. */

    bsp_init();
    printf("Initialised.\n");

    /* Initialise an array containing the current image. */

    memset((uint8_t*) &blank_image[0][0], 0xff, 176*33);
    current_image = (uint8_t*) &blank_image[0][0];
    printf("Set blank image.\n");

    /* Call epd_DisplayImg with the new image and current image. */

    epd_DisplayImg(DISPLAY_IN_USE, (uint8_t *) &image_data[0][0][0], current_image);
    printf("Updated image. Press Enter...\n");

    fgetc(stdin);

    /* Set the current image to the new image. */

    current_image = &image_data[0][0][0];

    /* Call epd_DisplayImg with the new image and current image. */

    epd_DisplayImg(DISPLAY_IN_USE, (uint8_t *) &image_data[1][0][0], current_image);
    printf("Updated image.\n");

    /* Detach from the board. */

    printf("Closing...\n");
    ubb_close(0);

    return 0;
}
